@@ -124,14 +124,17 @@ f_points <- function(plot, data = all_rows(),
     params$shape <- shape_converter(params$shape)
     if (params$shape %in% 21:24) {
       params$size <- params$size * 1.5
-      params$color <- "#FFFFFF"
+      if (("color" %in% names(params)) && !("fill" %in% names(params))) {
+        params$fill <- params$color
+      }
+      params$color <- plot$tidyplot$paper
     }
   }
 
   # Allow shape aesthetic to override shape
-  if("shape" %in% names(plot$mapping)) params$shape <- NULL
+  if ("shape" %in% names(plot$mapping)) params$shape <- NULL
   # Allow size aesthetic to override size
-  if("size" %in% names(plot$mapping)) params$size <- NULL
+  if ("size" %in% names(plot$mapping)) params$size <- NULL
 
   geom <- do.call(fun, params)
   add_geom(plot, geom, rasterize = rasterize, rasterize_dpi = rasterize_dpi, level = -1)
