@@ -1,8 +1,8 @@
 
 ff_adjust_axis <- function(axis) {
   function(plot, title = ggplot2::waiver(), breaks = ggplot2::waiver(),
-           labels = ggplot2::waiver(), limits = NULL, padding = c(NA, NA),
-           rotate_labels = FALSE, transform = "identity",
+           labels = NULL, limits = NULL,
+           padding = c(NA, NA), rotate_labels = FALSE, transform = "identity",
            cut_short_scale = FALSE, force_continuous = FALSE, ...) {
     plot <- check_tidyplot(plot)
   # Parse title
@@ -18,6 +18,12 @@ ff_adjust_axis <- function(axis) {
       plot <- plot + ggplot2::theme(axis.text.y = ggplot2::element_text(angle = rotate_labels, hjust = vjust, vjust = 1))
   }
 
+  # Adjust labels
+  if (axis == "x") plot$tidyplot$labels_x <- labels %||% plot$tidyplot$labels_x
+  if (axis == "y") plot$tidyplot$labels_y <- labels %||% plot$tidyplot$labels_y
+  labels_x <- plot$tidyplot$labels_x
+  labels_y <- plot$tidyplot$labels_y
+
   # Adjust limits
   if (axis == "x") plot$tidyplot$limits_x <- limits %||% plot$tidyplot$limits_x
   if (axis == "y") plot$tidyplot$limits_y <- limits %||% plot$tidyplot$limits_y
@@ -50,9 +56,9 @@ ff_adjust_axis <- function(axis) {
     # cli::cli_alert_success("adjust_{axis}_axis: {.pkg datetime}")
     suppressMessages(
       if (axis == "x")
-        plot <- plot + ggplot2::scale_x_datetime(name = title, breaks = breaks, labels = labels, expand = expand_x, ...)
+        plot <- plot + ggplot2::scale_x_datetime(name = title, breaks = breaks, labels = labels_x, expand = expand_x, ...)
       else
-        plot <- plot + ggplot2::scale_y_datetime(name = title, breaks = breaks, labels = labels, expand = expand_y, ...)
+        plot <- plot + ggplot2::scale_y_datetime(name = title, breaks = breaks, labels = labels_y, expand = expand_y, ...)
     )
     return(plot)
   }
@@ -62,9 +68,9 @@ ff_adjust_axis <- function(axis) {
     # cli::cli_alert_success("adjust_{axis}_axis: {.pkg date}")
     suppressMessages(
       if (axis == "x")
-        plot <- plot + ggplot2::scale_x_date(name = title, breaks = breaks, labels = labels, expand = expand_x, ...)
+        plot <- plot + ggplot2::scale_x_date(name = title, breaks = breaks, labels = labels_x, expand = expand_x, ...)
       else
-        plot <- plot + ggplot2::scale_y_date(name = title, breaks = breaks, labels = labels, expand = expand_y, ...)
+        plot <- plot + ggplot2::scale_y_date(name = title, breaks = breaks, labels = labels_y, expand = expand_y, ...)
     )
     return(plot)
   }
@@ -74,26 +80,26 @@ ff_adjust_axis <- function(axis) {
     # cli::cli_alert_success("adjust_{axis}_axis: {.pkg time}")
     suppressMessages(
       if (axis == "x")
-        plot <- plot + ggplot2::scale_x_time(name = title, breaks = breaks, labels = labels, expand = expand_x, ...)
+        plot <- plot + ggplot2::scale_x_time(name = title, breaks = breaks, labels = labels_x, expand = expand_x, ...)
       else
-        plot <- plot + ggplot2::scale_y_time(name = title, breaks = breaks, labels = labels, expand = expand_y, ...)
+        plot <- plot + ggplot2::scale_y_time(name = title, breaks = breaks, labels = labels_y, expand = expand_y, ...)
     )
     return(plot)
   }
 
   # Continuous
   if (is_continuous(plot, axis) || force_continuous) {
-    if (is_waiver(labels) && cut_short_scale)
-      labels <- scales::label_number(scale_cut = scales::cut_short_scale())
-    # cli::cli_alert_success("adjust_{axis}_axis: {.pkg continuous}")
-
     suppressMessages({
       if (axis == "x") {
-        if(!is_discrete(plot, "x")) {
-          plot <- plot + ggplot2::scale_x_continuous(name = title, breaks = breaks, labels = labels, limits = NULL, expand = expand_x, transform = transform, ...)}
+        if (!is_discrete(plot, "x")) {
+          if (is_waiver(labels_x) && cut_short_scale)
+            labels_x <- scales::label_number(scale_cut = scales::cut_short_scale())
+          plot <- plot + ggplot2::scale_x_continuous(name = title, breaks = breaks, labels = labels_x, limits = NULL, expand = expand_x, transform = transform, ...)}
       } else {
-        if(!is_discrete(plot, "y")) {
-          plot <- plot + ggplot2::scale_y_continuous(name = title, breaks = breaks, labels = labels, limits = NULL, expand = expand_y, transform = transform, ...)}
+        if (!is_discrete(plot, "y")) {
+          if (is_waiver(labels_y) && cut_short_scale)
+            labels_y <- scales::label_number(scale_cut = scales::cut_short_scale())
+          plot <- plot + ggplot2::scale_y_continuous(name = title, breaks = breaks, labels = labels_y, limits = NULL, expand = expand_y, transform = transform, ...)}
       }
     })
     return(plot)
@@ -101,18 +107,19 @@ ff_adjust_axis <- function(axis) {
 
   # Discrete
   if (is_discrete(plot, axis)) {
-    if (is_waiver(labels))
-      labels <- tidyplot_parse_labels()
-    # cli::cli_alert_success("adjust_{axis}_axis: {.pkg discrete}")
     suppressMessages(
-      if (axis == "x")
+      if (axis == "x") {
+        if (is_waiver(labels_x)) labels_x <- tidyplot_parse_labels()
         plot <- plot + ggplot2::scale_x_discrete(
-          name = title, breaks = breaks, labels = labels,
+          name = title, breaks = breaks, labels = labels_x,
           expand = ggplot2::waiver(), ...)
-      else
+      }
+      else {
+        if (is_waiver(labels_y)) labels_y <- tidyplot_parse_labels()
         plot <- plot + ggplot2::scale_y_discrete(
-          name = title, breaks = breaks, labels = labels,
+          name = title, breaks = breaks, labels = labels_y,
           expand = ggplot2::waiver(), ...)
+      }
     )
     return(plot)
   }
@@ -192,9 +199,8 @@ adjust_y_axis <- ff_adjust_axis("y")
 
 
 #' Adjust plot area size
-#' @param width Width of the plot area.
-#' @param height Height of the plot area.
-#' @param unit Unit of the plot area width and height.
+#' @param overall_width,overall_height The overall dimensions of a multiplot layout generated with `split_plot()`.
+#' @inheritParams tidyplot
 #' @inherit common_arguments
 #'
 #' @examples
@@ -231,9 +237,15 @@ adjust_y_axis <- ff_adjust_axis("y")
 #'   adjust_size(width = NA, height = NA)
 #'
 #' @export
-adjust_size <- function(plot, width = NULL, height = NULL, unit = NULL) {
+adjust_size <- function(plot, width = NULL, height = NULL, unit = NULL,
+                        overall_width = NULL, overall_height = NULL) {
   plot <- check_tidyplot(plot)
 
+  if (!is.null(width) && !is.null(overall_width))
+    cli::cli_alert_warning("Argument {.arg overall_width} overrules {.arg width} if both are specified.")
+  if (!is.null(height) && !is.null(overall_height))
+    cli::cli_alert_warning("Argument {.arg overall_height} overrules {.arg height} if both are specified.")
+
   plot$tidyplot$width <- width %||% plot$tidyplot$width
   plot$tidyplot$height <- height %||% plot$tidyplot$height
   plot$tidyplot$unit <- unit %||% plot$tidyplot$unit
@@ -242,10 +254,19 @@ adjust_size <- function(plot, width = NULL, height = NULL, unit = NULL) {
   height <- plot$tidyplot$height
   unit <- plot$tidyplot$unit
 
-  if (!is.na(width)) width <- ggplot2::unit(width, unit)
-  if (!is.na(height)) height <- ggplot2::unit(height, unit)
+  if (!is.null(overall_width)) {
+    if (!is.na(overall_width)) width <- ggplot2::unit(overall_width, unit) else width <- NULL
+  } else {
+    if (!is.na(width)) width <- ggplot2::unit(c(width, width), unit) else width <- NULL
+  }
 
-  plot + patchwork::plot_layout(widths = width, heights = height)
+  if (!is.null(overall_height)) {
+    if (!is.na(overall_height)) height <- ggplot2::unit(overall_height, unit) else height <- NULL
+  } else {
+    if (!is.na(height)) height <- ggplot2::unit(c(height, height), unit) else height <- NULL
+  }
+
+  plot + ggplot2::theme(panel.widths = width, panel.heights = height)
 }
 
 #' Adjust theme details
@@ -309,18 +330,20 @@ adjust_theme_details <- function(plot, ...) {
 #'   adjust_font(face = "bold")
 #'
 #' @export
-adjust_font <- function(plot, fontsize = 7, family = NULL, face = NULL, color = "black") {
+adjust_font <- function(plot, fontsize = 7, family = NULL, face = NULL) {
   plot <- check_tidyplot(plot)
   plot +
     ggplot2::theme(
-      plot.title = ggplot2::element_text(size = fontsize, family = family, face = face, colour = color, hjust = 0.5, vjust = 0.5),
-      plot.subtitle = ggplot2::element_text(size = fontsize, family = family, face = face, colour = color, hjust = 0.5, vjust = 0.5),
-      text = ggplot2::element_text(size = fontsize, family = family, face = face, colour = color),
-      axis.text = ggplot2::element_text(size = fontsize, family = family, face = face, colour = color),
-      axis.title = ggplot2::element_text(size = fontsize, family = family, face = face, colour = color),
-      legend.title = ggplot2::element_text(size = fontsize, family = family, face = face, colour = color),
-      legend.text = ggplot2::element_text(size = fontsize, family = family, face = face, colour = color),
-      strip.text = ggplot2::element_text(size = fontsize, family = family, face = face, colour = color),
+      plot.title = ggplot2::element_text(size = fontsize, family = family, face = face,
+                                         hjust = 0.5, vjust = 0.5),
+      plot.subtitle = ggplot2::element_text(size = fontsize, family = family, face = face,
+                                            hjust = 0.5, vjust = 0.5),
+      text = ggplot2::element_text(size = fontsize, family = family, face = face),
+      axis.text = ggplot2::element_text(size = fontsize, family = family, face = face),
+      axis.title = ggplot2::element_text(size = fontsize, family = family, face = face),
+      legend.title = ggplot2::element_text(size = fontsize, family = family, face = face),
+      legend.text = ggplot2::element_text(size = fontsize, family = family, face = face),
+      strip.text = ggplot2::element_text(size = fontsize, family = family, face = face),
       legend.key.size = ggplot2::unit(4, "mm")
     )
 }
@@ -393,7 +416,7 @@ adjust_font <- function(plot, fontsize = 7, family = NULL, face = NULL, color =
 #'   adjust_legend_position("none")
 #'
 #' @export
-adjust_legend_title <- function(plot, title = ggplot2::waiver(), fontsize = NULL, family = NULL, face = NULL, color = "black", ...) {
+adjust_legend_title <- function(plot, title = ggplot2::waiver(), fontsize = NULL, family = NULL, face = NULL, color = NULL, ...) {
   plot |> adjust_legend(title = title) +
     ggplot2::theme(legend.title = ggplot2::element_text(size = fontsize, family = family, face = face, colour = color, ...))
 }
@@ -512,25 +535,25 @@ adjust_padding <- function(plot, top = NA, right = NA, bottom = NA, left = NA, a
 #'   adjust_caption("$H[2]*O$")
 #'
 #' @export
-adjust_title <- function(plot, title = ggplot2::waiver(), fontsize = NULL, family = NULL, face = NULL, color = "black", ...) {
+adjust_title <- function(plot, title = ggplot2::waiver(), fontsize = NULL, family = NULL, face = NULL, color = NULL, ...) {
   plot |> adjust_description(title = title) +
     ggplot2::theme(plot.title = ggplot2::element_text(size = fontsize, family = family, face = face, colour = color, ...))
 }
 #' @rdname adjust_title
 #' @export
-adjust_x_axis_title <- function(plot, title = ggplot2::waiver(), fontsize = NULL, family = NULL, face = NULL, color = "black", ...) {
+adjust_x_axis_title <- function(plot, title = ggplot2::waiver(), fontsize = NULL, family = NULL, face = NULL, color = NULL, ...) {
   plot |> adjust_description(x_axis_title = title) +
     ggplot2::theme(axis.title.x = ggplot2::element_text(size = fontsize, family = family, face = face, colour = color))
 }
 #' @rdname adjust_title
 #' @export
-adjust_y_axis_title <- function(plot, title = ggplot2::waiver(), fontsize = NULL, family = NULL, face = NULL, color = "black", ...) {
+adjust_y_axis_title <- function(plot, title = ggplot2::waiver(), fontsize = NULL, family = NULL, face = NULL, color = NULL, ...) {
   plot |> adjust_description(y_axis_title = title) +
     ggplot2::theme(axis.title.y = ggplot2::element_text(size = fontsize, family = family, face = face, colour = color))
 }
 #' @rdname adjust_title
 #' @export
-adjust_caption <- function(plot, caption = ggplot2::waiver(), fontsize = NULL, family = NULL, face = NULL, color = "black", ...) {
+adjust_caption <- function(plot, caption = ggplot2::waiver(), fontsize = NULL, family = NULL, face = NULL, color = NULL, ...) {
   plot |> adjust_description(caption = caption) +
     ggplot2::theme(plot.caption = ggplot2::element_text(size = fontsize, family = family, face = face, colour = color))
 }
