@@ -1,6 +1,8 @@
 
-`%+%` <- ggplot2::`%+%`
-`%||%` <- rlang::`%||%`
+`%||%` <- function(x, y) {
+  if (is.null(x)) y else x
+}
+
 is_waiver <- function(x) inherits(x, "waiver")
 
 #' The pipe
@@ -172,6 +174,25 @@ format_p_value <- function(x, accuracy = 0.0001) {
 
 # internal helpers
 
+var_is_null <- function(var) {
+  quo_var <- rlang::enquo(var)
+  rlang::quo_is_null(quo_var)
+}
+
+var_as_name <- function(var) {
+  quo_var <- rlang::enquo(var)
+  rlang::as_name(quo_var)
+}
+
+# <ggplot> %+% x was deprecated in ggplot2 4.0.0.
+update_data <- function(plot, new_data) {
+  if (utils::packageVersion("ggplot2") > "3.5.2.9000") {
+    plot + new_data
+  } else {
+    ggplot2::`%+%`(plot, new_data)
+  }
+}
+
 format_number <- function(x, accuracy = 0.1, big.mark =",", scale_cut = NULL, ...) {
   scales::number(x = x, accuracy = accuracy, big.mark = big.mark, scale_cut = scale_cut, ...)
 }
@@ -197,7 +218,7 @@ mean_cl_boot <- function(x) {
 
 tidyplot_parser <- function(text) {
   # detect expressions by a leading and trailing "$"
-  if(any(stringr::str_detect(text, "^\\$.*\\$$"), na.rm = TRUE)) {
+  if (any(stringr::str_detect(text, "^\\$.*\\$$"), na.rm = TRUE)) {
     out <- vector("expression", length(text))
     for (i in seq_along(text)) {
       # get rid of leading and trailing "$"
@@ -381,7 +402,8 @@ get_layout_size <- function(plot, units = c("mm", "cm", "in")) {
   pages <-
     purrr::map(plot, function(x) {
       if (!ggplot2::is.ggplot(x)) cli::cli_abort("Argument {.arg plot} must be a {.pkg ggplot} or list of {.pkg ggplots}")
-      gtab <- patchwork::patchworkGrob(x)
+
+      gtab <- ggplot2::ggplotGrob(x)
 
       width <- NA
       height <- NA
