@@ -1,10 +1,8 @@
 #' Create a new tidyplot
 #'
 #' @param data A tidy `data.frame` to use for plotting.
-#' @param width Width of the plot area. The default (`NULL`) retrieves the setting from the
-#'   [tidyplots options][tidyplots_options], which defaults to `50`.
-#' @param height Height of the plot area. The default (`NULL`) retrieves the setting from the
-#'   [tidyplots options][tidyplots_options], which defaults to `50`.
+#' @param width,height Dimensions of the plot area. The default (`NULL`) retrieves the setting from the
+#'   [tidyplots options][tidyplots_options], which defaults to `50`. `NA` results in taking all available space (ggplot2 default).
 #' @param unit Unit of the plot area width and height. The default (`NULL`) retrieves the setting from the
 #'   [tidyplots options][tidyplots_options], which defaults to `"mm"`.
 #' @param dodge_width For adjusting the distance between grouped objects.
@@ -13,6 +11,10 @@
 #' at least one discrete axis and to `0` for plots with two continuous axes.
 #' @param my_style Styling function to apply to the plot. The default (`NULL`) retrieves the setting from the
 #'   [tidyplots options][tidyplots_options], which default to no additional styling.
+#' @param paper Background color. The default (`NULL`) retrieves the setting from the
+#'   [tidyplots options][tidyplots_options], which defaults to `"#FFFFFF"`.
+#' @param ink Foreground color. The default (`NULL`) retrieves the setting from the
+#'   [tidyplots options][tidyplots_options], which defaults to `"#000000"`.
 #' @param ... Mappings for the `x` axis, `y` axis and `color`, see examples.
 #' Additional argument are passed to `ggplot2::aes()`.
 #'
@@ -42,20 +44,22 @@ tidyplot <- function(data, ...,
                      height = NULL,
                      unit = NULL,
                      dodge_width = NULL,
-                     my_style = NULL) {
+                     my_style = NULL,
+                     paper = NULL,
+                     ink = NULL) {
   mapping <- ggplot2::aes(...)
 
   # Add .single_color column to data if `colour` and `fill` mappings are missing
   single_color_plot <- FALSE
-  if(!"colour" %in% names(mapping) && !"fill" %in% names(mapping)) {
+  if (!"colour" %in% names(mapping) && !"fill" %in% names(mapping)) {
     data$.single_color <- TRUE
     mapping$colour <- ggplot2::aes(colour = .single_color)[[1]]
     single_color_plot <- TRUE
   }
 
   # Align `colour` and `fill` mappings
-  if("colour" %in% names(mapping) && !"fill" %in% names(mapping)) mapping$fill <- mapping$colour
-  if("fill" %in% names(mapping) && !"colour" %in% names(mapping)) mapping$colour <- mapping$fill
+  if ("colour" %in% names(mapping) && !"fill" %in% names(mapping)) mapping$fill <- mapping$colour
+  if ("fill" %in% names(mapping) && !"colour" %in% names(mapping)) mapping$colour <- mapping$fill
 
   plot <- ggplot2::ggplot(data = data, mapping = mapping)
   class(plot) <- c("tidyplot", class(plot))
@@ -68,12 +72,18 @@ tidyplot <- function(data, ...,
   plot$tidyplot$height <- height %||% getOption("tidyplots.height") %||% 50
   plot$tidyplot$unit <- unit %||% getOption("tidyplots.unit") %||% "mm"
 
+  plot$tidyplot$paper <- paper %||% getOption("tidyplots.paper") %||% "#FFFFFF"
+  plot$tidyplot$ink <- ink %||% getOption("tidyplots.ink") %||% "#000000"
+
   plot$tidyplot$padding_x <- c(0.05, 0.05)
   plot$tidyplot$padding_y <- c(0.05, 0.05)
 
   plot$tidyplot$limits_x <- c(NULL, NULL)
   plot$tidyplot$limits_y <- c(NULL, NULL)
 
+  plot$tidyplot$labels_x <- ggplot2::waiver()
+  plot$tidyplot$labels_y <- ggplot2::waiver()
+
   # dodge_width_heuristic
   if (is_discrete(plot, "x") || is_discrete(plot, "y")) {
     dodge_width_heuristic <- 0.8
@@ -147,23 +157,36 @@ tidyplots_options <- function(
   height = NULL,
   unit = NULL,
   dodge_width = NULL,
-  my_style = NULL
+  my_style = NULL,
+  paper = NULL,
+  ink = NULL
 ) {
   opts <- options(
     tidyplots.width = width,
     tidyplots.height = height,
     tidyplots.unit = unit,
     tidyplots.dodge_width = dodge_width,
-    tidyplots.my_style = my_style
+    tidyplots.my_style = my_style,
+    tidyplots.paper = paper,
+    tidyplots.ink = ink
   )
   invisible(opts)
 }
 
 
 #' Split plot into multiple subplots
-#' @param by Variable that should be used for splitting.
-#' @param ncol,nrow The number of columns and rows per page.
-#' @inheritParams patchwork::wrap_plots
+#' @param by One variable that should be used for splitting.
+#' @param ncol,nrow The number of columns and rows per page. Only takes effect when using `by` to split by a single variable.
+#' @param rows,cols Two variables that should be used for splitting, representing rows and columns, respectively.
+#' @param axes Determines which axes will be drawn in case of fixed scales.
+#' When `"margins"`, axes will be drawn at the exterior margins. `"all_x"` and `"all_y"` will draw
+#' the respective axes at the interior panels too, whereas `"all"` (the default) will draw all axes at all panels.
+#' @param axis.titles Determines which axis titles will be drawn.
+#' When `"margins"`, axis titles will be drawn at the exterior margins. `"all"` (the default) will draw all axis titles at all panels.
+#' `"single"` will draw a single axis title per multiplot layout.
+#' @param scales Should scales be fixed `"fixed"`, free (`"free"`), or free in one dimension (`"free_x"`, `"free_y"`)?
+#' Defaults to `"free"` when providing one splitting variable via `by`.
+#' Defaults to `"fixed"` when providing two splitting variables via `rows` and `cols`.
 #' @inherit common_arguments
 #'
 #' @examples
@@ -198,53 +221,86 @@ tidyplots_options <- function(
 #'   adjust_size(width = 25, height = 25) |>
 #'   split_plot(by = year, ncol = 2, nrow = 1)
 #'
+#' # Split by two variables
+#' energy |>
+#'   dplyr::mutate(decade = paste0(floor(year / 10) * 10, "s")) |>
+#'   tidyplot(y = energy, color = energy_source) |>
+#'   add_donut() |>
+#'   adjust_size(14,14) |>
+#'   split_plot(rows = decade, cols = energy_type)
+#'
 #' @export
-split_plot <- function(plot, by, ncol = NULL, nrow = NULL, byrow = NULL,
-                       guides = "collect", tag_level = NULL, design = NULL) {
+split_plot <- function(plot, by = NULL, rows = NULL, cols = NULL, ncol = NULL, nrow = NULL,
+                       axes = "all", axis.titles = "all", scales = NULL, ...) {
   plot <- check_tidyplot(plot)
-  if(missing(by))
-    cli::cli_abort("Argument {.arg by} missing without default.")
 
-  widths <- plot$tidyplot$width
-  heights <- plot$tidyplot$height
-  unit <- plot$tidyplot$unit
+  error_msg <- "Specify the argument {.arg by} to split the plot by one variable.
+  Alternatively, specify the arguments {.arg rows} and {.arg cols} to split the plot by two variables."
+  if (var_is_null({{ by }}) && var_is_null({{ rows }}) && var_is_null({{ cols }}))
+    cli::cli_abort(error_msg)
+  if (!var_is_null({{ by }}) && (!var_is_null({{ rows }}) || !var_is_null({{ cols }})))
+    cli::cli_abort(error_msg)
 
-  if (!is.na(widths)) widths <- ggplot2::unit(widths, unit)
-  if (!is.na(heights)) heights <- ggplot2::unit(heights, unit)
+  do_facet_wrap <- do_facet_grid <- FALSE
+  if (!var_is_null({{ by }})) do_facet_wrap <- TRUE
+  if (!var_is_null({{ rows }}) || !var_is_null({{ cols }})) do_facet_grid <- TRUE
 
-  # free plot dimensions
-  plot <-
-    plot |>
-    adjust_size(width = NA, height = NA)
+  warning_msg <- "When splitting the plot by {.arg rows} and {.arg cols}, the arguments {.arg ncol} and {.arg nrow} are ignored."
+  if (do_facet_grid && (!var_is_null({{ ncol }}) || !var_is_null({{ nrow }})))
+    cli::cli_warn(warning_msg)
 
-  df <-
-    plot$data |>
-    tidyr::nest(data = -{{by}}) |>
-    dplyr::arrange({{by}})
+  # Facet wrap
+  if (do_facet_wrap) {
+    scales <- scales %||% "free"
 
-  plots <-
-    purrr::map2(df$data, df |> dplyr::pull({{by}}),
-         function(data, facet_title) {
-           plot %+% data + ggplot2::ggtitle(facet_title)
-         })
+    if (is.numeric(ncol) && is.numeric(nrow)) {
+      plots_per_page <- nrow * ncol
 
-  if (is.numeric(ncol) && is.numeric(nrow)) {
-    plots_per_page <- nrow * ncol
-  } else {
-    plots_per_page <- length(plots)
+      df <-
+        plot$data |>
+        tidyr::nest(data = -{{by}}) |>
+        dplyr::arrange({{by}})
+
+      dfs <- split(df, ceiling(seq_len(nrow(df)) / plots_per_page))
+
+      pages <-
+        dfs |>
+        purrr::map(function(x) {
+          new_data <- x |> tidyr::unnest(cols = data)
+          update_data(plot, new_data) +
+            facet_wrap_ext(
+              facets = ggplot2::vars({{ by }}),
+              nrow = nrow, ncol = ncol, scales = scales,
+              axes = axes, axis.titles = axis.titles, ...)
+        })
+
+      cli::cli_alert_success("split_plot: split into {.pkg {nrow(df)} plot{?s}} across {.pkg {ceiling(nrow(df)/plots_per_page)} page{?s}}")
+
+      return(unname(pages))
+    } else {
+      plot <- plot + facet_wrap_ext(
+        facets = ggplot2::vars({{ by }}),
+        nrow = nrow, ncol = ncol, scales = scales, axes = axes,
+        axis.titles = axis.titles, ...)
+      return(plot)
+    }
   }
 
-  pages <-
-    split(plots, ceiling(seq_along(plots)/plots_per_page)) |>
-    purrr::map(~patchwork::wrap_plots(.x, ncol = ncol, nrow = nrow, widths = widths,
-                                         heights = heights, guides = guides, byrow = byrow,
-                                         tag_level = tag_level, design = design))
+  # Facet grid
+  if (do_facet_grid) {
+    scales <- scales %||% "fixed"
 
-  cli::cli_alert_success("split_plot: split into {.pkg {length(plots)} plot{?s}} across {.pkg {ceiling(length(plots)/plots_per_page)} page{?s}}")
-
-  out <- unname(pages)
-  if (length(out) == 1) out <- out[[1]]
-  out
+    plot <- plot +
+      facet_grid_ext(rows = ggplot2::vars({{ rows }}),
+                          cols = ggplot2::vars({{ cols }}),
+                          axes = axes,
+                          axis.titles = axis.titles,
+                          scales = scales,
+                          switch = "y",
+                          ...) +
+      ggplot2::theme_sub_strip(placement = "outside")
+    return(plot)
+  }
 }
 
 
@@ -285,9 +341,9 @@ view_plot <- function(plot, data = all_rows(), title = ggplot2::waiver(), ...) {
   input <- plot
   if (inherits(data, "function")) {
     my_fun <- data
-    plot <- plot %+% (my_fun(plot$data)) + ggplot2::ggtitle(title)
+    plot <- update_data(plot, my_fun(plot$data)) + ggplot2::ggtitle(title)
   }
-  if (inherits(data, "data.frame")) plot <- plot %+% data + ggplot2::ggtitle(title)
+  if (inherits(data, "data.frame")) plot <- update_data(plot, data) + ggplot2::ggtitle(title)
   print(plot, ...)
   invisible(input)
 }
@@ -307,6 +363,7 @@ view_plot <- function(plot, data = all_rows(), title = ggplot2::waiver(), ...) {
 #' Defaults to `NA`. In case of `NA`, the dimensions are inferred from the
 #' incoming `plot` object (see Details).
 #' @param units Units of length. Defaults to `"mm"`.
+#' @param padding Extra space around the saved plot. Defaults to `0.1` meaning 10%.
 #' @param multiple_files Whether to save multiple pages as individual files.
 #' @param view_plot Whether to view the plot on screen after saving.
 #' @inheritParams ggplot2::ggsave
@@ -359,8 +416,8 @@ view_plot <- function(plot, data = all_rows(), title = ggplot2::waiver(), ...) {
 #'
 #' @export
 save_plot <- function(plot = ggplot2::last_plot(), filename,
-                      width = NA, height = NA, units = c("mm", "cm", "in"),
-                      multiple_files = FALSE, view_plot = TRUE, bg = "transparent", ...) {
+                      width = NA, height = NA, units = c("mm", "cm", "in"), padding = 0.1,
+                      multiple_files = FALSE, view_plot = TRUE, ...) {
   if (!ggplot2::is.ggplot(plot) && !all(purrr::map_lgl(plot, ggplot2::is.ggplot)))
     cli::cli_abort("{.arg plot} must be a single plot or a list of plots.")
 
@@ -368,18 +425,18 @@ save_plot <- function(plot = ggplot2::last_plot(), filename,
   if (ggplot2::is.ggplot(plot)) plot <- list(plot)
   units <- match.arg(units)
 
-  if (check_input(plot) %in% c("pw_list", "tp_list"))
+  if (check_input(plot) %in% c("pw_list", "tp_list", "gg_list"))
     dimensions <- get_layout_size(plot, units)$max
   else
     dimensions <- list(width = NA, height = NA)
 
-  if (is.na(width)) width <- dimensions[["width"]] * 1.1
-  if (is.na(height)) height <- dimensions[["height"]] * 1.1
+  if (is.na(width)) width <- dimensions[["width"]] * (1 + padding)
+  if (is.na(height)) height <- dimensions[["height"]] * (1 + padding)
 
   if (length(plot) == 1) {
     # single plot
     ggplot2::ggsave(plot = plot[[1]], filename = filename, width = width,
-                    height = height, units = units, bg = bg, ...)
+                    height = height, units = units, ...)
     cli::cli_alert_success("save_plot: saved to {.file {filename}}")
   } else{
     # multiple plots
@@ -403,7 +460,7 @@ save_plot <- function(plot = ggplot2::last_plot(), filename,
       purrr::map2(plot, filenames,
                   function(x, y) {
                     ggplot2::ggsave(plot = x, filename = y, width = width,
-                                    height = height, units = units, bg = bg, ...)
+                                    height = height, units = units, ...)
                   })
       cli::cli_alert_success("save_plot: saved multiple plots to {.file {filenames}}")
     }
