@@ -23,3 +23,16 @@ test_that("add boxplot and violin works", {
   #   add_data_points_beeswarm() |>
   #   vdiffr::expect_doppelganger("violin grouped", fig = _)
 })
+
+test_that("histograms work", {
+  energy |>
+    tidyplot(x = energy) |>
+    add_histogram() |>
+    vdiffr::expect_doppelganger("histogram", fig = _)
+
+  energy |>
+    tidyplot(x = energy) |>
+    add_histogram(color = "purple") |>
+    vdiffr::expect_doppelganger("histogram custom color", fig = _)
+})
+
